pub struct WindowedAggregate {
pub key_field: String,
pub win: WindowKind,
pub agg: AggKind,
/* private fields */
}Expand description
A stateful windowed aggregation operator supporting different windows & aggregations. A stateful windowed aggregation operator supporting different windows & aggregations.
Examples
use pulse_ops::WindowedAggregate;
// Tumbling count of words per 60s window
let op = WindowedAggregate::tumbling_count("word", 60_000);Fields
key_field: Stringwin: WindowKindagg: AggKindImplementations
Sourceimpl WindowedAggregate
impl WindowedAggregate
pub fn tumbling_count(key_field: impl Into<String>, size_ms: i64) -> Self
pub fn tumbling_sum( key_field: impl Into<String>, size_ms: i64, field: impl Into<String>, ) -> Self
pub fn tumbling_avg( key_field: impl Into<String>, size_ms: i64, field: impl Into<String>, ) -> Self
pub fn tumbling_distinct( key_field: impl Into<String>, size_ms: i64, field: impl Into<String>, ) -> Self
pub fn sliding_count( key_field: impl Into<String>, size_ms: i64, slide_ms: i64, ) -> Self
pub fn sliding_sum( key_field: impl Into<String>, size_ms: i64, slide_ms: i64, field: impl Into<String>, ) -> Self
pub fn sliding_avg( key_field: impl Into<String>, size_ms: i64, slide_ms: i64, field: impl Into<String>, ) -> Self
pub fn sliding_distinct( key_field: impl Into<String>, size_ms: i64, slide_ms: i64, field: impl Into<String>, ) -> Self
pub fn session_count(key_field: impl Into<String>, gap_ms: i64) -> Self
pub fn session_sum( key_field: impl Into<String>, gap_ms: i64, field: impl Into<String>, ) -> Self
pub fn session_avg( key_field: impl Into<String>, gap_ms: i64, field: impl Into<String>, ) -> Self
pub fn session_distinct( key_field: impl Into<String>, gap_ms: i64, field: impl Into<String>, ) -> Self
pub fn with_allowed_lateness(self, ms: i64) -> Self